@@ -109,7 +109,7 @@ pub struct EventContext {
     /// The AWS request ID generated by the Lambda service.
     pub aws_request_id: String,
     /// The X-Ray trace ID for the current invocation.
-    pub xray_trace_id: String,
+    pub xray_trace_id: Option<String>,
     /// The execution deadline for the current invocation in milliseconds.
     pub deadline: i64,
     /// The client context object sent by the AWS mobile SDK. This field is
@@ -269,9 +269,7 @@ impl<'ev> RuntimeClient {
     /// # Arguments
     ///
     /// * `request_id` The request id associated with the event we are serving the error for.
-    /// * `e` An instance of `errors::HandlerError` generated by the handler function. Handler
-    ///       functions can generate a new error using the `new_error(&str)` method of the `Context`
-    ///       object.
+    /// * `e` An instance of `errors::HandlerError` generated by the handler function.
     ///
     /// # Returns
     /// A `Result` object containing a bool return value for the call or an `error::ApiError` instance.
@@ -406,7 +404,17 @@ impl<'ev> RuntimeClient {
             headers.get(LambdaHeaders::FunctionArn.as_str()),
             &LambdaHeaders::FunctionArn,
         )?;
-        let xray_trace_id = header_string(headers.get(LambdaHeaders::TraceId.as_str()), &LambdaHeaders::TraceId)?;
+        let xray_trace_id = match headers.get(LambdaHeaders::TraceId.as_str()) {
+            Some(trace_id) => match trace_id.to_str() {
+                Ok(trace_str) => Some(trace_str.to_owned()),
+                Err(e) => {
+                    // we do not fail on this error.
+                    error!("Could not parse X-Ray trace id as string: {}", e);
+                    None
+                }
+            },
+            None => None,
+        };
         let deadline = header_string(headers.get(LambdaHeaders::Deadline.as_str()), &LambdaHeaders::Deadline)?
             .parse::<i64>()
             .context(ApiErrorKind::Recoverable(
@@ -463,3 +471,49 @@ fn header_string(value: Option<&HeaderValue>, header_type: &LambdaHeaders) -> Re
         }
     }
 }
+
+#[cfg(test)]
+pub(crate) mod tests {
+    use super::*;
+    use chrono::{Duration, Utc};
+
+    fn get_headers() -> HeaderMap<HeaderValue> {
+        let mut headers: HeaderMap<HeaderValue> = HeaderMap::new();
+        headers.insert(
+            LambdaHeaders::RequestId.as_str(),
+            HeaderValue::from_str("req_id").unwrap(),
+        );
+        headers.insert(
+            LambdaHeaders::FunctionArn.as_str(),
+            HeaderValue::from_str("func_arn").unwrap(),
+        );
+        headers.insert(LambdaHeaders::TraceId.as_str(), HeaderValue::from_str("trace").unwrap());
+        let deadline = Utc::now() + Duration::seconds(10);
+        headers.insert(
+            LambdaHeaders::Deadline.as_str(),
+            HeaderValue::from_str(&deadline.timestamp_millis().to_string()).unwrap(),
+        );
+        headers
+    }
+
+    #[test]
+    fn get_event_context_with_empty_trace_id() {
+        let client = RuntimeClient::new("localhost:8081", None, None).expect("Could not initialize runtime client");
+        let mut headers = get_headers();
+        headers.remove(LambdaHeaders::TraceId.as_str());
+        let headers_result = client.get_event_context(&headers);
+        assert_eq!(false, headers_result.is_err());
+        let ok_result = headers_result.unwrap();
+        assert_eq!(None, ok_result.xray_trace_id);
+        assert_eq!("req_id", ok_result.aws_request_id);
+    }
+
+    #[test]
+    fn get_event_context_populates_trace_id_when_present() {
+        let client = RuntimeClient::new("localhost:8081", None, None).expect("Could not initialize runtime client");
+        let headers = get_headers();
+        let headers_result = client.get_event_context(&headers);
+        assert_eq!(false, headers_result.is_err());
+        assert_eq!(Some("trace".to_owned()), headers_result.unwrap().xray_trace_id);
+    }
+}
